# MoaT-Thing

% start synopsis
% start main

This module manages things. As in, the stuff you own.

This is woefully incomplete, more a concept than real code, and a work in progress.

% end synopsis
% end main
